# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`candlepin`](#candlepin): Manage a Candlepin server

_Private Classes_

* `candlepin::config`: Configuration for Candlepin
* `candlepin::database::mysql`: Candlepin Database Setup using Mysql
* `candlepin::database::postgresql`: Candlepin Database Setup using Postgresql
* `candlepin::install`: Candlepin installation packages
* `candlepin::params`: Candlepin params
* `candlepin::qpid`: Qpid setup for Candlepin
* `candlepin::repo`: Manage the yum repository
* `candlepin::service`: Candlepin Service and Initialization

## Classes

### candlepin

Manage a Candlepin server

#### Parameters

The following parameters are available in the `candlepin` class.

##### `oauth_key`

Data type: `String`

The OAuth key for talking to the candlepin API

Default value: $candlepin::params::oauth_key

##### `oauth_secret`

Data type: `String`

The OAuth secret for talking to the candlepin API

Default value: $candlepin::params::oauth_secret

##### `manage_db`

Data type: `Boolean`

Whether a database should be installed, this includes db creation and user

Default value: $candlepin::params::manage_db

##### `init_db`

Data type: `Boolean`

Whether a database should be initialised.

Default value: $candlepin::params::init_db

##### `db_type`

Data type: `Enum['postgresql','mysql']`

The type of database Candlepin will be connecting too.

Default value: $candlepin::params::db_type

##### `db_host`

Data type: `String`

Hostname of database server.

Default value: $candlepin::params::db_host

##### `db_port`

Data type: `Optional[Integer[0, 65535]]`

Port the database listens on. Only needs to be provided if different from
standard port of the :db_type.

Default value: $candlepin::params::db_port

##### `db_ssl`

Data type: `Boolean`

Boolean indicating if the connection to the database should be over an SSL
connection.

Default value: $candlepin::params::db_ssl

##### `db_ssl_verify`

Data type: `Boolean`

Boolean indicating if the SSL connection to the database should be verified

Default value: $candlepin::params::db_ssl_verify

##### `db_name`

Data type: `String`

The name of the Candlepin database

Default value: $candlepin::params::db_name

##### `db_user`

Data type: `String`

The Candlepin database username

Default value: $candlepin::params::db_user

##### `db_password`

Data type: `String`

The Candlepin database password

Default value: $candlepin::params::db_password

##### `crl_file`

Data type: `Stdlib::Absolutepath`

The Certificate Revocation File for Candlepin

Default value: $candlepin::params::crl_file

##### `user_groups`

Data type: `Variant[Array[String], String]`

The user groups for the Candlepin tomcat user

Default value: $candlepin::params::user_groups

##### `log_dir`

Data type: `Stdlib::Absolutepath`

Directory for Candlepin logs

Default value: $candlepin::params::log_dir

##### `env_filtering_enabled`

Data type: `Boolean`

If subscription filtering is done on a per environment basis

Default value: $candlepin::params::env_filtering_enabled

##### `keystore_file`

Data type: `String`

Tomcat keystore file to use

Default value: $candlepin::params::keystore_file

##### `keystore_password`

Data type: `Optional[String]`

Password for keystore being used with Tomcat

Default value: $candlepin::params::keystore_password

##### `keystore_type`

Data type: `String`

Keystore type

Default value: $candlepin::params::keystore_type

##### `truststore_file`

Data type: `String`

Tomcat truststore file to use

Default value: $candlepin::params::truststore_file

##### `truststore_password`

Data type: `Optional[String]`

Password for truststore being used with Tomcat

Default value: $candlepin::params::truststore_password

##### `ca_key`

Data type: `Stdlib::Absolutepath`

CA key file to use

Default value: $candlepin::params::ca_key

##### `ca_cert`

Data type: `Stdlib::Absolutepath`

CA certificate file to use

Default value: $candlepin::params::ca_cert

##### `ca_key_password`

Data type: `Optional[String]`

CA key password

Default value: $candlepin::params::ca_key_password

##### `qpid_hostname`

Data type: `String`

The qpid server's hostname

Default value: $candlepin::params::qpid_hostname

##### `qpid_ssl_port`

Data type: `Integer[0,65535]`

The qpid server's SSL port

Default value: $candlepin::params::qpid_ssl_port

##### `qpid_ssl_cert`

Data type: `Optional[Stdlib::Absolutepath]`

Client certificate to talk to qpid server

Default value: $candlepin::params::qpid_ssl_cert

##### `qpid_ssl_key`

Data type: `Optional[Stdlib::Absolutepath]`

Client key to talk to qpid server

Default value: $candlepin::params::qpid_ssl_key

##### `ciphers`

Data type: `Array[String]`

Allowed ciphers for ssl connection

Default value: $candlepin::params::ciphers

##### `tls_versions`

Data type: `Array[String]`

Allowed versions of TLS, for example 1.1, 1.2, etc

Default value: $candlepin::params::tls_versions

##### `version`

Data type: `String`

Version of Candlepin to install

Default value: $candlepin::params::version

##### `wget_version`

Data type: `String`

Version of wget to install

Default value: $candlepin::params::wget_version

##### `run_init`

Data type: `Boolean`

If the init api should be called on Candlepin

Default value: $candlepin::params::run_init

##### `adapter_module`

Data type: `Optional[String]`

Candlepin adapter implementations to inject into the java runtime

Default value: $candlepin::params::adapter_module

##### `amq_enable`

Data type: `Boolean`

If amq should be enabled and configured

Default value: $candlepin::params::amq_enable

##### `amqp_keystore`

Data type: `Stdlib::Absolutepath`

Location of the amqp keystore to use

Default value: $candlepin::params::amqp_keystore

##### `amqp_keystore_password`

Data type: `Optional[String]`

Password for the amqp keystore

Default value: $candlepin::params::amqp_keystore_password

##### `amqp_truststore`

Data type: `Stdlib::Absolutepath`

Location of the amqp truststore to use

Default value: $candlepin::params::amqp_truststore

##### `amqp_truststore_password`

Data type: `Optional[String]`

Password for the amqp trusture

Default value: $candlepin::params::amqp_truststore_password

##### `enable_basic_auth`

Data type: `Boolean`

Whether to enable HTTP basic auth

Default value: $candlepin::params::enable_basic_auth

##### `enable_trusted_auth`

Data type: `Boolean`

Whether to enable trusted auth

Default value: $candlepin::params::enable_trusted_auth

##### `consumer_system_name_pattern`

Data type: `Optional[String]`

Regex that consistutes a valid consumer name

Default value: $candlepin::params::consumer_system_name_pattern

##### `enable_hbm2ddl_validate`

Data type: `Boolean`

If true will perform a schema check to ensure compliance with the models.
Disabling this feature may be required if modifications are required to schema

Default value: $candlepin::params::enable_hbm2ddl_validate

##### `ssl_port`

Data type: `Integer[0, 65535]`

Port to deploy SSL enabled Tomcat server on

Default value: $candlepin::params::ssl_port

##### `candlepin_conf_file`

Data type: `Stdlib::Absolutepath`

Configuration file location for candlepin

Default value: $candlepin::params::candlepin_conf_file

##### `manage_repo`

Data type: `Boolean`

Whether to manage the yum repository

Default value: $candlepin::params::manage_repo

##### `repo_version`

Data type: `String`

Which yum repository to install. For example latest or 3.3. Note that the
versions are Katello releases.

Default value: $candlepin::params::repo_version

##### `repo_gpgcheck`

Data type: `Boolean`

Whether to check the GPG signatures

Default value: $candlepin::params::repo_gpgcheck

##### `repo_gpgkey`

Data type: `Optional[String]`

The GPG key to use

Default value: $candlepin::params::repo_gpgkey

##### `tomcat_base`

Data type: `Stdlib::Absolutepath`

In new-style instances, if CATALINA_BASE isn't specified, it will be
constructed by joining TOMCATS_BASE and NAME.

Default value: $candlepin::params::tomcat_base

##### `java_home`

Data type: `Stdlib::Absolutepath`

Where your java installation lives

Default value: $candlepin::params::java_home

##### `catalina_home`

Data type: `Stdlib::Absolutepath`

Where your tomcat installation lives

Default value: $candlepin::params::catalina_home

##### `catalina_tmpdir`

Data type: `Stdlib::Absolutepath`

System-wide tmp

Default value: $candlepin::params::catalina_tmpdir

##### `java_opts`

Data type: `String`

Java Parameters

Default value: $candlepin::params::java_opts

##### `lang`

Data type: `Optional[String]`

Tomcat locale setting

Default value: $candlepin::params::lang

##### `security_manager`

Data type: `Boolean`

Run tomcat under the Java Security Manager

Default value: $candlepin::params::security_manager

##### `shutdown_wait`

Data type: `Optional[Integer[0]]`

Time to wait in seconds, before killing process

Default value: $candlepin::params::shutdown_wait

