# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`dhcp`](#dhcp): Manage an ISC DHCP server
* [`dhcp::disable`](#dhcpdisable): Remove and Disable the DHCP server
* [`dhcp::failover`](#dhcpfailover): Define a failover peer

_Private Classes_

* `dhcp::params`: Default parameters

**Defined types**

* [`dhcp::dhcp_class`](#dhcpdhcp_class): Define a DHCP class
* [`dhcp::host`](#dhcphost): Define a DHCP host reservation
* [`dhcp::pool`](#dhcppool): Define a DHCP pool

**Data types**

* [`Dhcp::Macaddress`](#dhcpmacaddress): 
* [`Dhcp::Range`](#dhcprange): 
* [`Dhcp::StaticRoute`](#dhcpstaticroute): 

## Classes

### dhcp

Manage an ISC DHCP server

#### Parameters

The following parameters are available in the `dhcp` class.

##### `dnsdomain`

Data type: `Array[String]`



Default value: $dhcp::params::dnsdomain

##### `nameservers`

Data type: `Array[String]`



Default value: ['8.8.8.8', '8.8.4.4']

##### `failover`

Data type: `Boolean`



Default value: `false`

##### `bootp`

Data type: `Optional[Boolean]`



Default value: `undef`

##### `ntpservers`

Data type: `Array[String]`



Default value: []

##### `interfaces`

Data type: `Optional[Array[String]]`



Default value: `undef`

##### `interface`

Data type: `String`



Default value: 'NOTSET'

##### `default_lease_time`

Data type: `Integer[0]`



Default value: 43200

##### `max_lease_time`

Data type: `Integer[0]`



Default value: 86400

##### `dnskeyname`

Data type: `String`



Default value: 'rndc-key'

##### `dnsupdatekey`

Data type: `Optional[String]`



Default value: `undef`

##### `dnsupdateserver`

Data type: `Optional[String]`



Default value: `undef`

##### `omapi`

Data type: `Boolean`



Default value: `true`

##### `omapi_name`

Data type: `Optional[String]`



Default value: `undef`

##### `omapi_algorithm`

Data type: `String`



Default value: 'HMAC-MD5'

##### `omapi_key`

Data type: `Optional[String]`



Default value: `undef`

##### `pxeserver`

Data type: `Optional[String]`



Default value: `undef`

##### `pxefilename`

Data type: `String`



Default value: $dhcp::params::pxefilename

##### `mtu`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### `bootfiles`

Data type: `Hash[String, String]`



Default value: $dhcp::params::bootfiles

##### `logfacility`

Data type: `String`



Default value: 'local7'

##### `dhcp_monitor`

Data type: `Boolean`



Default value: `true`

##### `dhcp_dir`

Data type: `Stdlib::Absolutepath`



Default value: $dhcp::params::dhcp_dir

##### `packagename`

Data type: `String`



Default value: $dhcp::params::packagename

##### `servicename`

Data type: `String`



Default value: $dhcp::params::servicename

##### `option_static_route`

Data type: `Any`



Default value: `undef`

##### `options`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `authoritative`

Data type: `Boolean`



Default value: `false`

##### `dhcp_root_group`

Data type: `String`



Default value: $dhcp::params::root_group

##### `ddns_updates`

Data type: `Boolean`



Default value: `false`

##### `ddns_domainname`

Data type: `Optional[String]`



Default value: `undef`

##### `ddns_rev_domainname`

Data type: `Optional[String]`



Default value: `undef`

##### `ddns_update_style`

Data type: `Enum['none', 'interim', 'standard']`



Default value: 'interim'

##### `pools`

Data type: `Hash[String, Hash]`



Default value: {}

##### `hosts`

Data type: `Hash[String, Hash]`



Default value: {}

##### `includes`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `config_comment`

Data type: `String`



Default value: 'dhcpd.conf'

### dhcp::disable

Remove and Disable the DHCP server

### dhcp::failover

Define a failover peer

#### Parameters

The following parameters are available in the `dhcp::failover` class.

##### `peer_address`

Data type: `String`

The address of the failover peer.

##### `role`

Data type: `Enum['primary', 'secondary']`



Default value: 'primary'

##### `address`

Data type: `String`



Default value: $facts['ipaddress']

##### `port`

Data type: `Variant[Integer[0, 65535], String]`



Default value: 519

##### `max_response_delay`

Data type: `Variant[Integer[0], String]`



Default value: 30

##### `max_unacked_updates`

Data type: `Variant[Integer[0], String]`



Default value: 10

##### `mclt`

Data type: `Variant[Integer[0], String]`



Default value: 300

##### `load_split`

Data type: `Variant[Integer[0], String]`



Default value: 128

##### `load_balance`

Data type: `Variant[Integer[0], String]`



Default value: 3

##### `omapi_key`

Data type: `Optional[String]`



Default value: `undef`

## Defined types

### dhcp::dhcp_class

Define a DHCP class

#### Parameters

The following parameters are available in the `dhcp::dhcp_class` defined type.

##### `parameters`

Data type: `Variant[Array[String], String]`

The parameters for the class definition. When specified as a string, it
will be used verbatim with a semi colon at the end. When specified as an
array, every string is used and appended with a semi colon.

### dhcp::host

Define a DHCP host reservation

#### Parameters

The following parameters are available in the `dhcp::host` defined type.

##### `ip`

Data type: `String`

The IP address in the reservation

##### `mac`

Data type: `Dhcp::Macaddress`

The host's MAC address

##### `comment`

Data type: `Optional[String]`

An optional comment for the host

Default value: `undef`

### dhcp::pool

Define a DHCP pool

#### Parameters

The following parameters are available in the `dhcp::pool` defined type.

##### `network`

Data type: `String`



##### `mask`

Data type: `String`



##### `gateway`

Data type: `Optional[String]`



Default value: `undef`

##### `pool_parameters`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `range`

Data type: `Variant[Array[Dhcp::Range], Optional[Dhcp::Range], Enum[''], Boolean]`



Default value: `undef`

##### `failover`

Data type: `Optional[String]`



Default value: `undef`

##### `options`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `parameters`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `mtu`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### `nameservers`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `pxeserver`

Data type: `Optional[String]`



Default value: `undef`

##### `pxefilename`

Data type: `Optional[String]`



Default value: `undef`

##### `domain_name`

Data type: `Optional[String]`



Default value: `undef`

##### `static_routes`

Data type: `Optional[Array[Dhcp::StaticRoute]]`



Default value: `undef`

##### `search_domains`

Data type: `Variant[Array[String], Optional[String]]`



Default value: `undef`

##### `raw_append`

Data type: `Optional[String]`



Default value: `undef`

##### `raw_prepend`

Data type: `Optional[String]`



Default value: `undef`

## Data types

### Dhcp::Macaddress

The Dhcp::Macaddress data type.

Alias of `Pattern[/^[0-9A-Fa-f]{1,2}(:[0-9A-Fa-f]{1,2}){5}$/]`

### Dhcp::Range

The Dhcp::Range data type.

Alias of `Pattern[/^(dynamic-bootp )?((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d)))(\/((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))|[0-9]+))?( ((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d)))(\/((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))|[0-9]+))?)?$/]`

### Dhcp::StaticRoute

The Dhcp::StaticRoute data type.

Alias of `Struct[{
    'mask'              => String,
    'gateway'           => String,
    Optional['network'] => String,
  }]`

