# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`pulp`](#pulp): Install and configure pulp
* [`pulp::admin`](#pulpadmin): Install and configure Pulp admin
* [`pulp::child`](#pulpchild): Install and configure Pulp node
* [`pulp::consumer`](#pulpconsumer): Install and configure Pulp consumers
* [`pulp::crane`](#pulpcrane): Install and configure Crane

_Private Classes_

* `pulp::admin::config`: Pulp Admin Configuration
* `pulp::admin::install`: Pulp Admin Install Packages
* `pulp::admin::login`: Ensure the user is logged in to execute commands
* `pulp::admin::params`: Pulp Admin Params
* `pulp::apache`: configure apache
* `pulp::broker`: Set up the broker
* `pulp::child::apache`: Define an Apache config for a Pulp node deployment
* `pulp::child::config`: Pulp Node Configuration
* `pulp::child::install`: Pulp Node Install Packages
* `pulp::child::service`: Pulp Node Service
* `pulp::config`: Pulp Master Configuration
* `pulp::consumer::config`: Pulp Consumer Configuration
* `pulp::consumer::install`: Pulp Consumer Install Packages
* `pulp::consumer::params`: Pulp Consumer Params
* `pulp::consumer::service`: Pulp Consumer Service Packages
* `pulp::crane::apache`: Sets up Apache for Crane
* `pulp::crane::config`: Configure Crane
* `pulp::crane::install`: Install Crane and dependencies
* `pulp::database`: Set up the pulp database
* `pulp::install`: Pulp Installation Packages
* `pulp::params`: Pulp Master Params
* `pulp::repo::upstream`: Create the yum repo definition for the upstream repository
* `pulp::service`: Pulp Master Service
* `pulp::squid`: The class to manage squid. This is used by pulp streamer.

**Defined types**

_Public Defined types_

* [`pulp::apache::fragment`](#pulpapachefragment): Provides the ability to specify fragments for the ssl virtual host defined for a Pulp server
* [`pulp::child::fragment`](#pulpchildfragment): provides the ability to specify fragments for the ssl virtual host defined for a pulp node
* [`pulp::scheduled_repo`](#pulpscheduled_repo): A wrapper that creates a pulp_Xrepo resource with and an associated pulp_schedule resource

_Private Defined types_

* `pulp::apache_plugin`: Define a the Apache config for a plugin

**Resource types**

* [`pulp_isorepo`](#pulp_isorepo): doc
* [`pulp_puppetrepo`](#pulp_puppetrepo): doc
* [`pulp_register`](#pulp_register): 
* [`pulp_role`](#pulp_role): doc
* [`pulp_rpmbind`](#pulp_rpmbind): Bind/unbind to an RPM repo
* [`pulp_rpmrepo`](#pulp_rpmrepo): doc
* [`pulp_schedule`](#pulp_schedule): doc

**Functions**

_Public Functions_


_Private Functions_

* `pulp::daily_schedule`: 

**Data types**

* [`Pulp::Iso8601TimeInterval`](#pulpiso8601timeinterval): https://en.wikipedia.org/wiki/ISO_8601#Time_intervals TODO: Actually implement a regex.

## Classes

### pulp

Install and configure pulp

#### Parameters

The following parameters are available in the `pulp` class.

##### `version`

Data type: `String`

pulp package version, it's passed to ensure parameter of package resource
can be set to specific version number, 'latest', 'present' etc.

Default value: $pulp::params::version

##### `crane_debug`

Data type: `Boolean`

Whether to enable crane debug logging

Default value: $pulp::params::crane_debug

##### `crane_port`

Data type: `Integer[1, 65535]`

Port for Crane to run on

Default value: $pulp::params::crane_port

##### `crane_data_dir`

Data type: `Stdlib::Absolutepath`

Directory containing docker v1/v2 artifacts published by pulp

Default value: $pulp::params::crane_data_dir

##### `manage_repo`

Data type: `Boolean`

Whether to manage the pulp repository

Default value: $pulp::params::manage_repo

##### `oauth_key`

Data type: `String`

Key to enable OAuth style authentication

Default value: $pulp::params::oauth_key

##### `oauth_secret`

Data type: `String`

Shared secret that can be used for OAuth style authentication

Default value: $pulp::params::oauth_secret

##### `oauth_enabled`

Data type: `Boolean`

Controls whether OAuth authentication is enabled

Default value: $pulp::params::oauth_enabled

##### `messaging_url`

Data type: `String`

the url used to contact the broker:
<protocol>://<host>:<port>/<virtual-host> Supported <protocol>  values are
'tcp' or 'ssl' depending on if SSL should be used or not. The
<virtual-host> is optional, and is only applicable to RabbitMQ broker
environments.

Default value: $pulp::params::messaging_url

##### `messaging_transport`

Data type: `Enum['qpid', 'rabbitmq']`

The type of broker you are connecting to.

Default value: $pulp::params::messaging_transport

##### `messaging_ca_cert`

Data type: `Optional[Stdlib::Absolutepath]`

Absolute path to PEM encoded CA certificate file, used by Pulp to validate
the identity of the broker using SSL.

Default value: $pulp::params::messaging_ca_cert

##### `messaging_client_cert`

Data type: `Optional[Stdlib::Absolutepath]`

Absolute path to PEM encoded file containing both the private key and
certificate Pulp should present to the broker to be authenticated by the
broker.

Default value: $pulp::params::messaging_client_cert

##### `messaging_version`

Data type: `String`

Determines the version of packages related to the 'messaging transport protocol'.

Default value: $pulp::params::messaging_version

##### `broker_url`

Data type: `String`

A URL to a broker that Celery can use to queue tasks:
qpid://<username>:<password>@<hostname>:<port>/

Default value: $pulp::params::broker_url

##### `broker_use_ssl`

Data type: `Boolean`

Whether to require SSL.

Default value: $pulp::params::broker_use_ssl

##### `tasks_login_method`

Data type: `Optional[String]`

Select the SASL login method used to connect to the broker. This should be
left unset except in special cases such as SSL client certificate
authentication.

Default value: $pulp::params::tasks_login_method

##### `ca_cert`

Data type: `Stdlib::Absolutepath`

Full path to the CA certificate that will be used to sign consumer and
admin identification certificates; this must match the value of
SSLCACertificateFile in Apache.

Default value: $pulp::params::ca_cert

##### `ca_key`

Data type: `Stdlib::Absolutepath`

Path to the private key for the above CA certificate

Default value: $pulp::params::ca_key

##### `db_name`

Data type: `String`

Name of the database to use

Default value: $pulp::params::db_name

##### `db_seeds`

Data type: `String`

Comma-separated list of hostname:port of database replica seed hosts

Default value: $pulp::params::db_seeds

##### `db_username`

Data type: `Optional[String]`

The user name to use for authenticating to the MongoDB server

Default value: $pulp::params::db_username

##### `db_password`

Data type: `Optional[String]`

The password to use for authenticating to the MongoDB server

Default value: $pulp::params::db_password

##### `db_replica_set`

Data type: `Optional[String]`

The name of replica set configured in MongoDB, if one is in use

Default value: $pulp::params::db_replica_set

##### `db_ssl`

Data type: `Boolean`

Whether to connect to the database server using SSL.

Default value: $pulp::params::db_ssl

##### `db_ssl_keyfile`

Data type: `Optional[Stdlib::Absolutepath]`

A path to the private keyfile used to identify the local connection
against mongod. If included with the certfile then only the ssl_certfile
is needed.

Default value: $pulp::params::db_ssl_keyfile

##### `db_ssl_certfile`

Data type: `Optional[Stdlib::Absolutepath]`

The certificate file used to identify the local connection against mongod.

Default value: $pulp::params::db_ssl_certfile

##### `db_verify_ssl`

Data type: `Boolean`

Specifies whether a certificate is required from the other side of the
connection, and whether it will be validated if provided. If it is true,
then the ca_certs parameter must point to a file of CA certificates used
to validate the connection.

Default value: $pulp::params::db_verify_ssl

##### `db_ca_path`

Data type: `Stdlib::Absolutepath`

The ca_certs file contains a set of concatenated "certification authority"
certificates, which are used to validate certificates passed from the
other end of the connection.

Default value: $pulp::params::db_ca_path

##### `db_unsafe_autoretry`

Data type: `Boolean`

If true, retry commands to the database if there is a connection error.
Warning: if set to true, this setting can result in duplicate records.

Default value: $pulp::params::db_unsafe_autoretry

##### `db_write_concern`

Data type: `Optional[Enum['majority', 'all']]`

Write concern of 'majority' or 'all'. When 'all' is specified, 'w' is set
to number of seeds specified. For version of MongoDB < 2.6, replica_set
must also be specified. Please note that 'all' will cause Pulp to halt if
any of the replica set members is not available. 'majority' is used by
default

Default value: $pulp::params::db_write_concern

##### `server_name`

Data type: `String`

Hostname the admin client and consumers should use when accessing the server

Default value: $pulp::params::server_name

##### `key_url`

Data type: `String`

Path within the URL to use for GPG keys

Default value: $pulp::params::key_url

##### `ks_url`

Data type: `String`

Path within the URL to use for kickstart trees

Default value: $pulp::params::ks_url

##### `debugging_mode`

Data type: `Boolean`

Whether to enable Pulp's debugging capabilities

Default value: $pulp::params::debugging_mode

##### `log_level`

Data type: `Enum['CRITICAL', 'ERROR', 'WARNING', 'INFO', 'DEBUG', 'NOTSET']`

The desired logging level.

Default value: $pulp::params::log_level

##### `log_type`

The desired logging type: Options are: syslog, console

##### `server_working_directory`

Data type: `Optional[Stdlib::Absolutepath]`

Path to where pulp workers can create working directories needed to complete tasks

Default value: $pulp::params::server_working_directory

##### `rsa_key`

Data type: `Stdlib::Absolutepath`

The RSA private key used for authentication.

Default value: $pulp::params::rsa_key

##### `rsa_pub`

Data type: `Stdlib::Absolutepath`

The RSA public key used for authentication.

Default value: $pulp::params::rsa_pub

##### `https_cert`

Data type: `Optional[Stdlib::Absolutepath]`

Apache public certificate for ssl

Default value: $pulp::params::https_cert

##### `https_key`

Data type: `Optional[Stdlib::Absolutepath]`

Apache private certificate for ssl

Default value: $pulp::params::https_key

##### `https_chain`

Data type: `Optional[Stdlib::Absolutepath]`

apache chain file for ssl

Default value: $pulp::params::https_chain

##### `ssl_username`

Data type: `Variant[String, Boolean]`

Value to use for SSLUsername directive in apache vhost. Defaults to
SSL_CLIENT_S_DN_CN. Set an empty string or false to unset directive.

Default value: $pulp::params::ssl_username

##### `consumers_crl`

Data type: `Optional[Stdlib::Absolutepath]`

Certificate revocation list for consumers which are no valid (have had
their client certs revoked)

Default value: $pulp::params::consumers_crl

##### `user_cert_expiration`

Data type: `Integer`

Number of days a user certificate is valid

Default value: $pulp::params::user_cert_expiration

##### `default_login`

Data type: `String`

Default admin username of the Pulp server; this user will be the first
time the server is started

Default value: $pulp::params::default_login

##### `default_password`

Data type: `String`

Default password for admin when it is first created; this should be
changed once the server is operational

Default value: $pulp::params::default_password

##### `repo_auth`

Data type: `Boolean`

Whether to determine whether repos managed by pulp will require authentication.

Default value: $pulp::params::repo_auth

##### `consumer_cert_expiration`

Data type: `Integer`

Number of days a consumer certificate is valid

Default value: $pulp::params::consumer_cert_expiration

##### `disabled_authenticators`

Data type: `Array[String]`

List of repo authenticators to disable.

Default value: $pulp::params::disabled_authenticators

##### `additional_wsgi_scripts`

Data type: `Hash[String, String]`

Hash of additional paths and WSGI script locations for Pulp vhost

Default value: $pulp::params::additional_wsgi_scripts

##### `reset_cache`

Data type: `Boolean`

Whether to force a cache flush. Not recommend in a regular puppet environment.

Default value: $pulp::params::reset_cache

##### `ssl_verify_client`

Data type: `Enum['none', 'optional', 'require', 'optional_no_ca']`

Enforce use of SSL authentication for yum repos access

Default value: $pulp::params::ssl_verify_client

##### `ssl_protocol`

Data type: `Variant[Array[String], String]`

Versions of the SSL/TLS protocol will be accepted in new connections

Default value: $pulp::params::ssl_protocol

##### `serial_number_path`

Data type: `Stdlib::Absolutepath`

Path to the serial number file

Default value: $pulp::params::serial_number_path

##### `consumer_history_lifetime`

Data type: `Integer[-1]`

number of days to store consumer events; events older than this will be
purged; set to -1 to disable

Default value: $pulp::params::consumer_history_lifetime

##### `messaging_url`

the url used to contact the broker:
<protocol>://<host>:<port>/<virtual-host> Supported <protocol>  values are
'tcp' or 'ssl' depending on if SSL should be used or not.  The
<virtual-host> is optional, and is only applicable to RabbitMQ broker
environments.

Default value: $pulp::params::messaging_url

##### `messaging_auth_enabled`

Data type: `Boolean`

Whether to enable message authentication.

Default value: $pulp::params::messaging_auth_enabled

##### `messaging_topic_exchange`

Data type: `String`

The name of the exchange to use. The exchange must be a topic exchange.
The default 'amq.topic' is a default exchange that is guaranteed to exist
on a Qpid broker.

Default value: $pulp::params::messaging_topic_exchange

##### `messaging_event_notifications_enabled`

Data type: `Boolean`

Whether to enable Pulp event notfications on the message bus.

Default value: $pulp::params::messaging_event_notifications_enabled

##### `messaging_event_notification_url`

Data type: `Optional[String]`

The AMQP URL for event notifications.

Default value: $pulp::params::messaging_event_notification_url

##### `email_host`

Data type: `String`

Hostname of the MTA pulp should relay through

Default value: $pulp::params::email_host

##### `email_port`

Data type: `Integer[1, 65535]`

Port of the MTA relay

Default value: $pulp::params::email_port

##### `email_from`

Data type: `String`

The "From" address of each email the system sends

Default value: $pulp::params::email_from

##### `email_enabled`

Data type: `Boolean`

Whether emails will be sent

Default value: $pulp::params::email_enabled

##### `manage_squid`

Data type: `Boolean`

Whether the Squid configuration is managed. This is used by Pulp Streamer.
Requires the squid module.

Default value: $pulp::params::manage_squid

##### `lazy_redirect_host`

Data type: `Optional[String]`

The host FQDN or IP to which requests are redirected.

Default value: $pulp::params::lazy_redirect_host

##### `lazy_redirect_port`

Data type: `Optional[Integer[1, 65535]]`

The TCP port to which requests are redirected

Default value: $pulp::params::lazy_redirect_port

##### `lazy_redirect_path`

Data type: `Optional[String]`

The base path to which requests are redirected

Default value: $pulp::params::lazy_redirect_path

##### `lazy_https_retrieval`

Data type: `Boolean`

Controls whether Pulp uses HTTPS or HTTP to retrieve content from the streamer.
WARNING: Setting this to 'false' is not safe if you wish to use Pulp to
provide repository entitlement enforcement.  It is strongly recommended to
keep this set to 'true' and use certificates that are signed by a trusted
authority on the web server that serves as the streamer reverse proxy.

Default value: $pulp::params::lazy_https_retrieval

##### `lazy_download_interval`

Data type: `Integer[0]`

The interval in minutes between checks for content cached by the Squid proxy.

Default value: $pulp::params::lazy_download_interval

##### `lazy_download_concurrency`

Data type: `Integer[0]`

The number of downloads to perform concurrently when downloading content
from the Squid cache.

Default value: $pulp::params::lazy_download_concurrency

##### `proxy_url`

Data type: `Optional[String]`

URL of the proxy server

Default value: $pulp::params::proxy_url

##### `proxy_port`

Data type: `Optional[Integer[1, 65535]]`

Port the proxy is running on

Default value: $pulp::params::proxy_port

##### `proxy_username`

Data type: `Optional[String]`

Proxy username for authentication

Default value: $pulp::params::proxy_username

##### `proxy_password`

Data type: `Optional[String]`

Proxy password for authentication

Default value: $pulp::params::proxy_password

##### `yum_max_speed`

Data type: `Optional[String]`

The maximum download speed for RPM & ISO Pulp tasks, such as a sync. (e.g.
"4 kb" or "1 Gb")

Default value: $pulp::params::yum_max_speed

##### `yum_gpg_sign_repo_metadata`

Data type: `Boolean`

Whether yum repo metadata GPG signing will be enabled

Default value: $pulp::params::yum_gpg_sign_repo_metadata

##### `num_workers`

Data type: `Integer[0]`

Number of Pulp workers to use.

Default value: $pulp::params::num_workers

##### `enable_admin`

Data type: `Boolean`

Whether to install and configure the admin command

Default value: $pulp::params::enable_admin

##### `enable_katello`

Data type: `Boolean`

Whether to enable pulp katello plugin.

Default value: $pulp::params::enable_katello

##### `enable_crane`

Data type: `Boolean`

Whether to enable crane docker repository

Default value: $pulp::params::enable_crane

##### `max_tasks_per_child`

Data type: `Optional[Integer[0]]`

Number of tasks after which the worker is restarted and the memory it
allocated is returned to the system

Default value: $pulp::params::max_tasks_per_child

##### `enable_rpm`

Data type: `Boolean`

Whether to enable rpm plugin.

Default value: $pulp::params::enable_rpm

##### `enable_deb`

Data type: `Boolean`

Whether to enable deb plugin.

Default value: $pulp::params::enable_deb

##### `enable_iso`

Data type: `Boolean`

Whether to enable iso plugin.

Default value: $pulp::params::enable_iso

##### `enable_docker`

Data type: `Boolean`

Whether to enable docker plugin.

Default value: $pulp::params::enable_docker

##### `enable_puppet`

Data type: `Boolean`

Whether to enable puppet plugin.

Default value: $pulp::params::enable_puppet

##### `enable_python`

Data type: `Boolean`

Whether to enable python plugin.

Default value: $pulp::params::enable_python

##### `enable_ostree`

Data type: `Boolean`

Whether to enable ostree plugin.

Default value: $pulp::params::enable_ostree

##### `enable_parent_node`

Data type: `Boolean`

Whether to enable pulp parent nodes.

Default value: $pulp::params::enable_parent_node

##### `enable_http`

Data type: `Boolean`

Whether to enable http access to deb/rpm repos.

Default value: $pulp::params::enable_http

##### `http_port`

Data type: `Integer[1, 65535]`

HTTP port Apache will listen

Default value: $pulp::params::http_port

##### `https_port`

Data type: `Integer[1, 65535]`

HTTPS port Apache will listen

Default value: $pulp::params::https_port

##### `manage_httpd`

Data type: `Boolean`

Whether to install and configure the httpd server.

Default value: $pulp::params::manage_httpd

##### `manage_plugins_httpd`

Data type: `Boolean`

Whether to install the enabled pulp plugins apache configs even if
$manage_httpd is false.

Default value: $pulp::params::manage_plugins_httpd

##### `manage_broker`

Data type: `Boolean`

Whether install and configure the qpid or rabbitmq broker.

Default value: $pulp::params::manage_broker

##### `manage_db`

Data type: `Boolean`

Boolean to install and configure the mongodb.

Default value: $pulp::params::manage_db

##### `node_certificate`

Data type: `Stdlib::Absolutepath`

The absolute path to the node SSL certificate

Default value: $pulp::params::node_certificate

##### `node_verify_ssl`

Data type: `Boolean`

Whether to verify node SSL

Default value: $pulp::params::node_verify_ssl

##### `node_server_ca_cert`

Data type: `Stdlib::Absolutepath`

Server cert for pulp node

Default value: $pulp::params::node_server_ca_cert

##### `node_oauth_effective_user`

Data type: `String`

Effective user for node OAuth

Default value: $pulp::params::node_oauth_effective_user

##### `node_oauth_key`

Data type: `String`

The oauth key used to authenticate to the parent node

Default value: $pulp::params::node_oauth_key

##### `node_oauth_secret`

Data type: `String`

The oauth secret used to authenticate to the parent node

Default value: $pulp::params::node_oauth_secret

##### `max_keep_alive`

Data type: `Integer[0]`

Configuration value for apache MaxKeepAliveRequests

Default value: $pulp::params::max_keep_alive

##### `wsgi_processes`

Data type: `Integer[1]`

Number of WSGI processes to spawn for pulp itself

Default value: $pulp::params::wsgi_processes

##### `wsgi_max_requests`

Data type: `Integer[0]`

Maximum number of requests for each wsgi worker to process before shutting
down and restarting, useful to combat memory leaks.

Default value: $pulp::params::wsgi_max_requests

##### `puppet_wsgi_processes`

Data type: `Integer[0]`

Number of WSGI processes to spawn for the puppet webapp

Default value: $pulp::params::puppet_wsgi_processes

##### `migrate_db_timeout`

Data type: `Integer[0]`

Change the timeout for pulp-manage-db

Default value: $pulp::params::migrate_db_timeout

##### `show_conf_diff`

Data type: `Boolean`

Allow showing diff for changes in server.conf and importer.json.
Warning: may display and log passwords contained in these files.

Default value: $pulp::params::show_conf_diff

##### `enable_profiling`

Data type: `Boolean`

Turns on cProfiling of tasks in Pulp

Default value: $pulp::params::enable_profiling

##### `profiling_directory`

Data type: `Stdlib::Absolutepath`

Directory to store task profiling data in

Default value: $pulp::params::profiling_directory

##### `ldap_url`

Data type: `Optional[String]`

URL to use for LDAP authentication. Defaults to undef (internal
authentication is used)

Default value: $pulp::params::ldap_url

##### `ldap_bind_dn`

Data type: `Optional[String]`

LDAP Bind DN

Default value: $pulp::params::ldap_bind_dn

##### `ldap_bind_password`

Data type: `Optional[String]`

LDAP Password

Default value: $pulp::params::ldap_bind_password

##### `ldap_remote_user_attribute`

Data type: `String`

LDAP Remote User Attribute. Defaults to 'sAMAccountName'

Default value: $pulp::params::ldap_remote_user_attribute

##### `worker_timeout`

Data type: `Integer[0]`

The amount of time (in seconds) before considering a worker as missing. If
Pulp's mongo database has slow I/O, then setting a higher number may
resolve issues where workers are going missing incorrectly. Defaults to 30.

Default value: $pulp::params::worker_timeout

### pulp::admin

Install and configure Pulp admin

#### Parameters

The following parameters are available in the `pulp::admin` class.

##### `version`

Data type: `String`

Pulp admin package version, it's passed to ensure parameter of package
resource can be set to specific version number, 'latest', 'present' etc.

Default value: $pulp::admin::params::version

##### `host`

Data type: `String`

The pulp server hostname

Default value: $pulp::admin::params::host

##### `port`

Data type: `Integer[1, 65535]`

The port providing the RESTful API

Default value: $pulp::admin::params::port

##### `api_prefix`

Data type: `String`

The REST API prefix.

Default value: $pulp::admin::params::api_prefix

##### `verify_ssl`

Data type: `Boolean`

Set this to False to configure the client not to verify that the server's
SSL cert is signed by a trusted authority

Default value: $pulp::admin::params::verify_ssl

##### `ca_path`

Data type: `Stdlib::Absolutepath`

This is a path to a file of concatenated trusted CA certificates, or to a
directory of trusted CA certificates (with openssl-style hashed symlinks,
one certificate per file).

Default value: $pulp::admin::params::ca_path

##### `upload_chunk_size`

Data type: `Integer[0]`

upload_chunk_size

Default value: $pulp::admin::params::upload_chunk_size

##### `role`

Data type: `String`

The client role.

Default value: $pulp::admin::params::role

##### `extensions_dir`

Data type: `Stdlib::Absolutepath`

The location of admin client extensions.

Default value: $pulp::admin::params::extensions_dir

##### `id_cert_dir`

Data type: `String`

The location of the directory where the Pulp user ID certificate is stored.

Default value: $pulp::admin::params::id_cert_dir

##### `id_cert_filename`

Data type: `String`

The name of the file containing the PEM encoded client private key and
X.509 certificate. This file is downloaded and stored here during login.

Default value: $pulp::admin::params::id_cert_filename

##### `upload_working_dir`

Data type: `String`

Directory where status files for in progress uploads will be stored

Default value: $pulp::admin::params::upload_working_dir

##### `log_filename`

Data type: `String`

The location of the admin client log file.

Default value: $pulp::admin::params::log_filename

##### `call_log_filename`

Data type: `String`

If present, the raw REST responses will be logged to the given file.

Default value: $pulp::admin::params::call_log_filename

##### `poll_frequency_in_seconds`

Data type: `Integer[0]`

Number of seconds between requests for any operation that repeatedly polls
the server for data.

Default value: $pulp::admin::params::poll_frequency_in_seconds

##### `enable_color`

Data type: `Boolean`

Set this to false to disable all color escape sequences

Default value: $pulp::admin::params::enable_color

##### `wrap_to_terminal`

Data type: `Boolean`

If wrap_to_terminal is true, any text wrapping will use the current width
of the terminal. If false, the value in wrap_width is used.

Default value: $pulp::admin::params::wrap_to_terminal

##### `wrap_width`

Data type: `Integer[0]`

The number of characters written before wrapping to the next line.

Default value: $pulp::admin::params::wrap_width

##### `enable_puppet`

Data type: `Boolean`

Install puppet extension. Defaults to false.

Default value: $pulp::admin::params::enable_puppet

##### `enable_deb`

Data type: `Boolean`

Install deb extension. Defaults to false.

Default value: $pulp::admin::params::enable_deb

##### `enable_docker`

Data type: `Boolean`

Install docker extension. Defaults to false.

Default value: $pulp::admin::params::enable_docker

##### `enable_nodes`

Data type: `Boolean`

Install nodes extension. Defaults to false.

Default value: $pulp::admin::params::enable_nodes

##### `enable_python`

Data type: `Boolean`

Install python extension. Defaults to false.

Default value: $pulp::admin::params::enable_python

##### `enable_ostree`

Data type: `Boolean`

Install ostree extension. Defaults to false.

Default value: $pulp::admin::params::enable_ostree

##### `enable_rpm`

Data type: `Boolean`

Install rpm extension. Defaults to true.

Default value: $pulp::admin::params::enable_rpm

##### `enable_iso`

Data type: `Boolean`

Install ISO extension. Defaults to true.

Default value: $pulp::admin::params::enable_iso

##### `puppet_upload_working_dir`

Data type: `String`

Directory where status files for in progress uploads will be stored

Default value: $pulp::admin::params::puppet_upload_working_dir

##### `puppet_upload_chunk_size`

Data type: `Integer[0]`

Maximum amount of data (in bytes) sent for an upload in a single request

Default value: $pulp::admin::params::puppet_upload_chunk_size

##### `login_method`

Data type: `Enum['none', 'file', 'login']`

The method to ensure root can use pulp-admin. Choose none to disable this
behaviour.

Default value: $pulp::admin::params::login_method

##### `username`

Data type: `String`

The username to login with

Default value: $pulp::admin::params::username

##### `password`

Data type: `Optional[String]`

The password to login with. If left undefined then no login will be
performed.

Default value: $pulp::admin::params::username

### pulp::child

Install and configure Pulp node

#### Parameters

The following parameters are available in the `pulp::child` class.

##### `parent_fqdn`

Data type: `String[1]`



##### `oauth_effective_user`

Data type: `String`



Default value: 'admin'

##### `oauth_key`

Data type: `String`



Default value: 'key'

##### `oauth_secret`

Data type: `String`



Default value: 'secret'

##### `ssl_cert`

Data type: `Stdlib::Absolutepath`



Default value: '/etc/pki/pulp/ssl_apache.crt'

##### `ssl_key`

Data type: `Stdlib::Absolutepath`



Default value: '/etc/pki/pulp/ssl_apache.key'

##### `server_ca_cert`

Data type: `Stdlib::Absolutepath`



Default value: '/etc/pki/pulp/ca.crt'

### pulp::consumer

Install and configure Pulp consumers

#### Parameters

The following parameters are available in the `pulp::consumer` class.

##### `ca_path`

Data type: `Stdlib::Absolutepath`

Path to use for the CA

Default value: $pulp::consumer::params::ca_path

##### `version`

Data type: `String`

pulp admin package version, it's passed to ensure parameter of package
resource can be set to specific version number, 'latest', 'present' etc.

Default value: $pulp::consumer::params::version

##### `enable_puppet`

Data type: `Boolean`

Install puppet extension

Default value: $pulp::consumer::params::enable_puppet

##### `enable_nodes`

Data type: `Boolean`

Install nodes extension

Default value: $pulp::consumer::params::enable_nodes

##### `enable_rpm`

Data type: `Boolean`

Install rpm extension

Default value: $pulp::consumer::params::enable_rpm

##### `host`

Data type: `String`

The pulp server hostname

Default value: $pulp::consumer::params::host

##### `port`

Data type: `Integer`

The port providing the RESTful API

Default value: $pulp::consumer::params::port

##### `api_prefix`

Data type: `String`

The REST API prefix.

Default value: $pulp::consumer::params::api_prefix

##### `verify_ssl`

Data type: `Boolean`

Set this to False to configure the client not to verify that the server's
SSL cert is signed by a trusted authority

Default value: $pulp::consumer::params::verify_ssl

##### `rsa_server_pub`

Data type: `Stdlib::Absolutepath`

The pulp server public key used for authentication.

Default value: $pulp::consumer::params::rsa_server_pub

##### `rsa_key`

Data type: `Stdlib::Absolutepath`

The RSA private key used for authentication.

Default value: $pulp::consumer::params::rsa_key

##### `rsa_pub`

Data type: `Stdlib::Absolutepath`

The RSA public key used for authentication.

Default value: $pulp::consumer::params::rsa_pub

##### `role`

Data type: `String`

The client role.

Default value: $pulp::consumer::params::role

##### `extensions_dir`

Data type: `Stdlib::Absolutepath`

The location of consumer client extensions.

Default value: $pulp::consumer::params::extensions_dir

##### `repo_file`

Data type: `Stdlib::Absolutepath`

The location of the YUM repository file managed by pulp.

Default value: $pulp::consumer::params::repo_file

##### `mirror_list_dir`

Data type: `Stdlib::Absolutepath`

The location of the directory containing YUM mirror list files that are
managed by Pulp.

Default value: $pulp::consumer::params::mirror_list_dir

##### `gpg_keys_dir`

Data type: `Stdlib::Absolutepath`

The location of downloaded GPG keys stored by Pulp. The path to the keys
stored here are referenced by Pulp's YUM repository file.

Default value: $pulp::consumer::params::gpg_keys_dir

##### `cert_dir`

Data type: `Stdlib::Absolutepath`

The location of downloaded X.509 certificates stored by Pulp. The path to
the certificates stored here are referenced by Pulp's YUM repository file.

Default value: $pulp::consumer::params::cert_dir

##### `id_cert_dir`

Data type: `Stdlib::Absolutepath`

The location of the directory where the Pulp consumer ID certificate is stored.

Default value: $pulp::consumer::params::id_cert_dir

##### `id_cert_filename`

Data type: `String`

The name of the file containing the PEM encoded consumer private key and
X.509 certificate. This file is downloaded and stored here during
registration.

Default value: $pulp::consumer::params::id_cert_filename

##### `reboot_permit`

Data type: `Boolean`

Permit reboots after package installs if requested.

Default value: $pulp::consumer::params::reboot_permit

##### `reboot_delay`

Data type: `Integer`

The reboot delay (minutes).

Default value: $pulp::consumer::params::reboot_delay

##### `logging_filename`

Data type: `String`

The location of the consumer client log file.

Default value: $pulp::consumer::params::logging_filename

##### `logging_call_log_filename`

Data type: `String`

If present, the raw REST responses will be logged to the given file.

Default value: $pulp::consumer::params::logging_call_log_filename

##### `poll_frequency_in_seconds`

Data type: `Integer`

Number of seconds between requests for any operation that repeatedly polls
the server for data.

Default value: $pulp::consumer::params::poll_frequency_in_seconds

##### `enable_color`

Data type: `Boolean`

Set this to false to disable all color escape sequences

Default value: $pulp::consumer::params::enable_color

##### `wrap_to_terminal`

Data type: `Boolean`

If wrap_to_terminal is true, any text wrapping will use the current width
of the terminal. If false, the value in wrap_width is used.

Default value: $pulp::consumer::params::wrap_to_terminal

##### `wrap_width`

Data type: `Integer`

The number of characters written before wrapping to the next line.

Default value: $pulp::consumer::params::wrap_width

##### `messaging_scheme`

Data type: `String`

The broker URL scheme. Either 'tcp' or 'ssl' can be used. The default is 'tcp'.

Default value: $pulp::consumer::params::messaging_scheme

##### `messaging_host`

Data type: `String`

The broker host (default: host defined in [server]).

Default value: $pulp::consumer::params::messaging_host

##### `messaging_port`

Data type: `Integer[0, 65535]`

The broker port number. The default is 5672.

Default value: $pulp::consumer::params::messaging_port

##### `messaging_transport`

Data type: `String`

The AMQP transport name. Valid options are 'qpid' or 'rabbitmq'. The
default is 'qpid'.

Default value: $pulp::consumer::params::messaging_transport

##### `messaging_vhost`

Data type: `Optional[String]`

The (optional) broker vhost. This is only valid when using 'rabbitmq' as
the messaging_transport.

Default value: $pulp::consumer::params::messaging_vhost

##### `messaging_version`

Data type: `String`

Determines the version of packages related to the 'messaging transport
protocol'.

Default value: $pulp::consumer::params::messaging_version

##### `messaging_cacert`

Data type: `Optional[Stdlib::Absolutepath]`

The (optional) absolute path to a PEM encoded CA certificate to validate
the identity of the broker.

Default value: $pulp::consumer::params::messaging_cacert

##### `messaging_clientcert`

Data type: `Optional[Stdlib::Absolutepath]`

The optional absolute path to PEM encoded key & certificate used to
authenticate to the broker with. The id_cert_dir and id_cert_filename are
used if this is not defined.

Default value: $pulp::consumer::params::messaging_clientcert

##### `profile_minutes`

Data type: `Integer[0]`

The interval in minutes for reporting the installed content profiles.

Default value: $pulp::consumer::params::profile_minutes

##### `package_profile_enabled`

Data type: `Integer`

Updates package profile information for a registered consumer on pulp server

Default value: $pulp::consumer::params::package_profile_enabled

##### `package_profile_verbose`

Data type: `Integer`

Set logging level

Default value: $pulp::consumer::params::package_profile_verbose

### pulp::crane

Install and configure Crane

#### Parameters

The following parameters are available in the `pulp::crane` class.

##### `debug`

Data type: `Boolean`

Enable debug logging

Default value: `false`

##### `server_name`

Data type: `Stdlib::Fqdn`

The server name on the vhost

Default value: $::fqdn

##### `key`

Data type: `Stdlib::Absolutepath`

Path to the SSL key for https

##### `cert`

Data type: `Stdlib::Absolutepath`

Path to the SSL certificate for https

##### `ca_cert`

Data type: `Stdlib::Absolutepath`

Path to the SSL CA cert for https

##### `ssl_chain`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the SSL chain file for https

Default value: `undef`

##### `port`

Data type: `Stdlib::Port`

Port for Crane to run on

Default value: 5000

##### `data_dir`

Data type: `Stdlib::Absolutepath`

Directory containing docker v1/v2 artifacts published by pulp

Default value: '/var/lib/crane/metadata'

##### `data_dir_polling_interval`

Data type: `Integer[0]`

The number of seconds between checks for updates to metadata files in the data_dir

Default value: 60

##### `ssl_protocol`

Data type: `Optional[String]`

SSLProtocol configuration to use

Default value: `undef`

## Defined types

### pulp::apache::fragment

Provides the ability to specify fragments for the ssl virtual host defined
for a Pulp server

#### Parameters

The following parameters are available in the `pulp::apache::fragment` defined type.

##### `ssl_content`

Data type: `String`

Content of the ssl virtual host fragment

##### `order`

Data type: `Integer`

The order in which to load the concat fragments

Default value: 15

### pulp::child::fragment

provides the ability to specify fragments for the ssl virtual host defined
for a pulp node

#### Parameters

The following parameters are available in the `pulp::child::fragment` defined type.

##### `ssl_content`

Data type: `Any`

Content of the ssl virtual host fragment

Default value: `undef`

##### `order`

Data type: `Any`

The relative order compared to other fragments

Default value: 15

### pulp::scheduled_repo

A wrapper that creates a pulp_Xrepo resource with and an associated pulp_schedule resource

#### Examples

##### Basic usage with default `rpm` `repo_type` and 'random' daily schedule

```puppet
pulp::scheduled_repo { 'centos-7':
  repo_config => {
    'display_name' => 'CentOS 7 Base Repo',
    'feed'         => 'https://www.mirrorservice.org/sites/mirror.centos.org/7/os/x86_64',
  },
}
```

#### Parameters

The following parameters are available in the `pulp::scheduled_repo` defined type.

##### `repo_type`

Data type: `Enum['rpm','puppet','iso']`

Determines whether a `pulp_rpmrepo`, `pulp_puppetrepo` or `pulp_isorepo` resource is created.

Default value: 'rpm'

##### `repo_config`

Data type: `Hash`

Defines a hash of parameters to pass to the `pulp_Xrepo` resource.

Default value: {}

##### `repo_schedule`

Data type: `Variant[Enum['daily'],Pulp::Iso8601TimeInterval]`

An iso8601 schedule string or the special value 'daily'. Defaults to 'daily' which creates a `pulp_schedule` with a pseudo-random daily `schedule_time`.

Default value: 'daily'

## Resource types

### pulp_isorepo

doc

#### Properties

The following properties are available in the `pulp_isorepo` type.

##### `ensure`

Valid values: present, absent

Create/Remove pulp iso repo.

Default value: present

##### `display_name`

user-readable display name (may contain i18n characters)

##### `description`

user-readable description (may contain i18n characters)

##### `note`

adds/updates/deletes notes to programmatically identify the resource

##### `feed`

URL of the external source repository to sync

##### `validate`

if "true", the size and checksum of each synchronized file will
be verified against the repo metadata

Default value: false

##### `feed_ca_cert`

full path to the CA certificate that should be used to
verify the external repo server's SSL certificate

##### `verify_feed_ssl`

if "true", the feed\'s SSL certificate will be verified
against the feed_ca_cert

Default value: false

##### `feed_cert`

full path to the certificate to use for authorization when accessing the external feed

##### `feed_key`

full path to the private key for feed_cert

##### `proxy_host`

proxy server url to use

##### `proxy_port`

Valid values: /^\d+$/

port on the proxy server to make requests

##### `proxy_user`

username used to authenticate with the proxy server

##### `proxy_pass`

password used to authenticate with the proxy server

##### `max_downloads`

Valid values: /^\d+$/

maximum number of downloads that will run concurrently

##### `max_speed`

Valid values: /^\d+$/

maximum bandwidth used per download thread, in bytes/sec,
when synchronizing the repo

##### `remove_missing`

if "true", units that were previously in the external
feed but are no longer found will be removed from the  repository

Default value: false

##### `serve_http`

if "true", the repository will be served over HTTP

Default value: false

##### `serve_https`

if "true", the repository will be served over HTTPS

Default value: true

#### Parameters

The following parameters are available in the `pulp_isorepo` type.

##### `name`

namevar

repo-id: uniquely identifies the rpm repo

##### `conf_file`

path to pulp-admin's config file. Defaults to /etc/pulp/admin/admin.conf

Default value: /etc/pulp/admin/admin.conf

### pulp_puppetrepo

doc

#### Properties

The following properties are available in the `pulp_puppetrepo` type.

##### `ensure`

Valid values: present, absent

Create/Remove pulp rpm repo.

Default value: present

##### `display_name`

user-readable display name (may contain i18n characters)

##### `description`

user-readable description (may contain i18n characters)

##### `note`

adds/updates/deletes notes to programmatically identify the resource

##### `feed`

URL of the external source repository to sync

##### `validate`

Whether the size and checksum of each synchronized file will
be verified against the repo metadata

Default value: false

##### `feed_ca_cert`

Full path to the CA certificate that should be used to
verify the external repo server's SSL certificate

##### `verify_feed_ssl`

Whether the feed\'s SSL certificate will be verified against the feed_ca_cert

Default value: false

##### `feed_cert`

full path to the certificate to use for authorization when
accessing the external feed

##### `feed_key`

full path to the private key for feed_cert

##### `proxy_host`

proxy server url to use

##### `proxy_port`

Valid values: /^\d+$/

port on the proxy server to make requests

##### `proxy_user`

username used to authenticate with the proxy server

##### `proxy_pass`

password used to authenticate with the proxy server

##### `max_downloads`

Valid values: /^\d+$/

maximum number of downloads that will run concurrently

##### `max_speed`

Valid values: /^\d+$/

maximum bandwidth used per download thread, in bytes/sec,
when synchronizing the repo

##### `serve_http`

if "true", the repository will be served over HTTP

Default value: false

##### `serve_https`

if "true", the repository will be served over HTTPS

Default value: true

##### `queries`

comma-separated list of queries to issue against the feed's
modules.json file to scope which modules are imported.
ignored when feed is static files.

#### Parameters

The following parameters are available in the `pulp_puppetrepo` type.

##### `name`

namevar

repo-id: uniquely identifies the rpm repo

##### `conf_file`

path to pulp-admin's config file. Defaults to /etc/pulp/admin/admin.conf

Default value: /etc/pulp/admin/admin.conf

### pulp_register

The pulp_register type.

#### Properties

The following properties are available in the `pulp_register` type.

##### `ensure`

Valid values: present, absent

Register/unregister a pulp consumer.

Default value: present

##### `display_name`

user-readable display name for the consumer

Default value: false

##### `description`

user-readable description for the consumer

Default value: false

##### `note`

note

Default value: false

#### Parameters

The following parameters are available in the `pulp_register` type.

##### `name`

namevar

uniquely identifies the consumer; only alphanumeric, ., -, and _ allowed

##### `user`



Default value: admin

##### `pass`



Default value: admin

##### `keys`

exchange public keys with the server

Default value: `false`

### pulp_role

doc

#### Properties

The following properties are available in the `pulp_role` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `users`

users to add to this role

##### `permissions`

resources/permissions to grant to this role

#### Parameters

The following parameters are available in the `pulp_role` type.

##### `name`

namevar

role-id: uniquely identifies the role

### pulp_rpmbind

Bind/unbind to an RPM repo

#### Properties

The following properties are available in the `pulp_rpmbind` type.

##### `ensure`

Valid values: present, absent

Bind/unbind to an RPM repo

Default value: present

#### Parameters

The following parameters are available in the `pulp_rpmbind` type.

##### `repo_id`

namevar

The repo-id

### pulp_rpmrepo

doc

#### Properties

The following properties are available in the `pulp_rpmrepo` type.

##### `ensure`

Valid values: present, absent

Create/Remove pulp rpm repo.

Default value: present

##### `display_name`

user-readable display name (may contain i18n characters)

##### `description`

user-readable description (may contain i18n characters)

##### `note`

adds/updates/deletes notes to programmatically identify the  resource

##### `feed`

URL of the external source repository to sync

##### `validate`

if "true", the size and checksum of each synchronized file will
be verified against the repo metadata

##### `skip`

Valid values: rpm, drpm, distribution, erratum

comma-separated list of types to omit when synchronizing, if not
specified all types will be synchronized; valid values are: rpm,
drpm, distribution, erratum

##### `feed_ca_cert`

full path to the CA certificate that should be used to
verify the external repo server's SSL certificate

##### `verify_feed_ssl`

if "true", the feed\'s SSL certificate will be verified against the feed_ca_cert

##### `feed_cert`

full path to the certificate to use for authorization when
accessing the external feed

##### `feed_key`

full path to the private key for feed_cert

##### `proxy_host`

proxy server url to use

##### `proxy_port`

Valid values: /^\d+$/

port on the proxy server to make requests

##### `proxy_user`

username used to authenticate with the proxy server

##### `proxy_pass`

password used to authenticate with the proxy server

##### `max_downloads`

Valid values: /^\d+$/

maximum number of downloads that will run concurrently

##### `max_speed`

Valid values: /^\d+$/

maximum bandwidth used per download thread, in bytes/sec,
when synchronizing the repo

##### `remove_missing`

if "true", units that were previously in the external
feed but are no longer found will be removed from the repository

##### `retain_old_count`

Valid values: /^\d+$/

count indicating how many non-latest versions of a unit
to keep in a repository

##### `relative_url`

relative path the repository will be served from. Only
alphanumeric characters, forward slashes, underscores and
dashes are allowed.

##### `serve_http`

if "true", the repository will be served over HTTP

##### `serve_https`

if "true", the repository will be served over HTTPS

##### `checksum_type`

type of checksum to use during metadata generation

##### `gpg_key`

File containing public GPG keys used to validate the signatures of RPMs and metadata in this repository.
These keys will be made available to consumers to use for verifying content in the repository.
The value provided to this option must be the full path to a GPG key file containing one or more ASCII armored public keys.

##### `generate_sqlite`

if "true", sqlite files will be generated for the repository metadata during publish

##### `host_ca`

full path to the CA certificate that signed the repository
hosts's SSL certificate when serving over HTTPS

##### `auth_ca`

full path to the CA certificate that should be used to verify
client authentication certificates; setting this turns on client
authentication for the repository

##### `auth_cert`

full path to the entitlement certificate that will be given to
bound consumers to grant access to this repository

##### `updateinfo_checksum_type`

type of checksum to use during updateinfo.xml generation

##### `repoview`

if "true", static HTML files will be generated
during publish by the repoview tool for faster
browsing of the repository. Enables
--generate-sqlite flag.

##### `require_signature`

if "Require that imported packages should be signed.

##### `allowed_keys`

List of allowed signature keys that imported packages
can be signed with. Comma separated values.

##### `download_policy`

Valid values: immediate, background, on_demand

content downloading policy

##### `basicauth_user`

username used to authenticate with sync location via HTTP basic auth

##### `basicauth_pass`

password used to authenticate with sync location via HTTP basic auth

#### Parameters

The following parameters are available in the `pulp_rpmrepo` type.

##### `name`

namevar

repo-id: uniquely identifies the rpm repo

##### `conf_file`

path to pulp-admin's config file. Defaults to /etc/pulp/admin/admin.conf

Default value: /etc/pulp/admin/admin.conf

### pulp_schedule

doc

#### Properties

The following properties are available in the `pulp_schedule` type.

##### `ensure`

Valid values: present, absent

Create/Remove pulp repo schedules.

Default value: present

##### `schedule_time`

time to execute in iso8601 format
(yyyy-mm-ddThh:mm:ssZ/PiuT); the number of
recurrences may be specified in this value

##### `enabled`

if "false", the schedule will exist but will not trigger any executions

Default value: true

##### `failure_threshold`

Valid values: /^\d+$/

number of failures before the schedule is
automatically disabled; unspecified means the
schedule will never be automatically disabled

#### Parameters

The following parameters are available in the `pulp_schedule` type.

##### `name`

namevar

repo-id: uniquely identifies the rpm repo

## Functions

## Data types

### Pulp::Iso8601TimeInterval

https://en.wikipedia.org/wiki/ISO_8601#Time_intervals
TODO: Actually implement a regex.

Alias of `String[1]`

